@@ -41,7 +41,7 @@ end
 
 ######
 
-package 'dstat' do
+package 'jq' do
   action :install
 end
 
@@ -55,35 +55,43 @@ package "ruby"
 
 gem_package 'tzinfo' do
   version '1.1.0'
+  cwd '/tmp'
 end
 
 gem_package 'tzinfo' do
   version '1.2.2'
+  cwd '/tmp'
 end
 
 gem_package 'rake' do
   version '11.1.0'
+  cwd '/tmp'
 end
 
 gem_package 'rake' do
   version '11.2.2'
+  cwd '/tmp'
 end
 
 gem_package 'rake' do
   action :uninstall
   version '11.2.2'
+  cwd '/tmp'
 end
 
 gem_package 'test-unit' do
   version '2.5.5'
+  cwd '/tmp'
 end
 
 gem_package 'test-unit' do
   version '2.4.9'
+  cwd '/tmp'
 end
 
 gem_package 'test-unit' do
   action :uninstall
+  cwd '/tmp'
 end
 
 ######
@@ -184,36 +192,38 @@ end
 
 ######
 
-http_request "/tmp/http_request.html" do
-  url "https://httpbin.org/get?from=itamae"
-end
+unless ENV["SKIP_HTTP_REQUEST_TEST"] == "true"
+  http_request "/tmp/http_request.html" do
+    url "https://httpbin.org/get?from=itamae"
+  end
 
-http_request "/tmp/http_request_delete.html" do
-  action :delete
-  url "https://httpbin.org/delete?from=itamae"
-end
+  http_request "/tmp/http_request_delete.html" do
+    action :delete
+    url "https://httpbin.org/delete?from=itamae"
+  end
 
-http_request "/tmp/http_request_post.html" do
-  action :post
-  message "love=sushi"
-  url "https://httpbin.org/post?from=itamae"
-end
+  http_request "/tmp/http_request_post.html" do
+    action :post
+    message "love=sushi"
+    url "https://httpbin.org/post?from=itamae"
+  end
 
-http_request "/tmp/http_request_put.html" do
-  action :put
-  message "love=sushi"
-  url "https://httpbin.org/put?from=itamae"
-end
+  http_request "/tmp/http_request_put.html" do
+    action :put
+    message "love=sushi"
+    url "https://httpbin.org/put?from=itamae"
+  end
 
-http_request "/tmp/http_request_headers.html" do
-  headers "User-Agent" => "Itamae"
-  url "https://httpbin.org/get"
-end
+  http_request "/tmp/http_request_headers.html" do
+    headers "User-Agent" => "Itamae"
+    url "https://httpbin.org/get"
+  end
 
-# http_request "/tmp/http_request_redirect.html" do
-#   redirect_limit 1
-#   url "https://httpbin.org/redirect-to?url=https%3A%2F%2Fhttpbin.org%2Fget%3Ffrom%3Ditamae"
-# end
+  # http_request "/tmp/http_request_redirect.html" do
+  #   redirect_limit 1
+  #   url "https://httpbin.org/redirect-to?url=https%3A%2F%2Fhttpbin.org%2Fget%3Ffrom%3Ditamae"
+  # end
+end
 
 link "/tmp-link" do
   to "/tmp"
